==> mediawiki_1.15.1.orig.tar.gz: mediawiki-1.15.1/languages/messages/MessagesFj.php <==
<?php
/** Fijian (Na Vosa Vakaviti)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

$messages = array(
# Dates
'sunday'        => 'Sigatabu',
'monday'        => 'Moniti',
'tuesday'       => 'Tusiti',
'wednesday'     => 'Vukelulu',
'thursday'      => 'Lotulevu',
'friday'        => 'Vakaraubuka',
'saturday'      => 'Vakarauwai',
'sun'           => 'Sigatabu',
'mon'           => 'Moniti',
'tue'           => 'Tusiti',
'wed'           => 'Vukelulu',
'thu'           => 'Lotulevu',
'fri'           => 'Vakaraubuka',
'sat'           => 'Vakarauwai',
'january'       => 'Janueri',
'february'      => 'Veverueri',
'march'         => 'Maji',
'april'         => 'Epereli',
'july'          => 'Jiulai',
'august'        => 'Okosita',
'september'     => 'Seviteba',
'october'       => 'Okotova',
'november'      => 'Noveba',
'december'      => 'Tiseba',
'january-gen'   => 'Janueri',
'february-gen'  => 'Veverueri',
'march-gen'     => 'Maji',
'april-gen'     => 'Evereli',
'may-gen'       => 'Me',
'july-gen'      => 'Jiulai',
'august-gen'    => 'Okosita',
'september-gen' => 'Seviteba',
'october-gen'   => 'Okotova',
'november-gen'  => 'Noveba',
'december-gen'  => 'Tiseba',
'jan'           => 'Janueri',
'feb'           => 'Veverueri',
'mar'           => 'Maji',
'apr'           => 'Epereli',
'may'           => 'Me',
'jun'           => 'June',
'jul'           => 'Julai',
'aug'           => 'Okosita',
'sep'           => 'Seviteba',
'oct'           => 'Okotova',
'nov'           => 'Noveba',
'dec'           => 'Tiseba',

'cancel'     => 'Sasamaki',
'qbedit'     => 'Veisautaki',
'mytalk'     => 'Noqu vosa',
'navigation' => 'Vakatasosoko',

'help'             => 'Veivuke',
'search'           => 'Vaqaqara',
'searchbutton'     => 'Vaqaqara',
'go'               => 'Lako',
'searcharticle'    => 'Lako',
'history_short'    => 'Tukuni',
'printableversion' => 'Tikina e rawa ni tabaki',
'permalink'        => 'Sema tudei',
'edit'             => 'Veisautaki',
'delete'           => 'Vakarusa',
'protect'          => 'Taqomaki',
'unprotect'        => 'Sega ni taqomaki',
'talk'             => 'Veiwasei',
'toolbox'          => 'Kato ni yaya',
'otherlanguages'   => 'Veimataqali vosa',
'jumptonavigation' => 'Vakatasosoko',
'jumptosearch'     => 'Vaqaqara',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Tukutuku kuruvaki',
'currentevents-url'    => 'Project:Tukutuku kuruvaki',
'edithelp'             => 'Veivukei',
'mainpage'             => 'Tabana levu',
'mainpage-description' => 'Tabana levu',
'portal'               => 'Soqosoqo toso',

'editsection' => 'Veisautaki',
'editold'     => 'Veisautaki',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Vola volai',

# Login and logout pages
'yourname'           => 'Yaca vakayagataki',
'yourpassword'       => 'Yaca vuni',
'yourpasswordagain'  => 'Vola tale na Yaca vuni',
'remembermypassword' => 'Nanuma na yacaqu ena komipiuta oqo',
'login'              => 'Curu mai',
'userlogin'          => 'Curu mai / Dolava nomu Akaude',
'logout'             => 'Curu yani',
'userlogout'         => 'Curu yani',
'nologinlink'        => 'Dolava nomu Akaude',
'createaccount'      => 'Dolava nomu Akaude',
'gotaccountlink'     => 'Curu mai',
'youremail'          => 'I vola livaliva *:',
'username'           => 'Yaca vakayagataki:',
'email'              => 'I vola livaliva',

# Edit pages
'summary'      => 'Kena i Soqoni:',
'watchthis'    => 'Vakaraica toka na tabana oqo',
'savearticle'  => 'Vakabula na tabana oqo',
'showpreview'  => 'Vakaraitaka na kenai yaloyalo',
'showdiff'     => 'Vakaritaka na veisau',
'loginreqlink' => 'Curu mai',

# Search results
'powersearch' => 'Vaqaqara',

# Preferences page
'mypreferences'     => 'Ulutaga taleitaki',
'searchresultshead' => 'Vaqaqara',

# Recent changes
'recentchanges' => 'Veisau vovou',

# Recent changes linked
'recentchangeslinked' => 'Veisau e veiwekani',

# Upload
'upload'            => 'Vakasinaita',
'uploadbtn'         => 'Vakasinaita',
'filedesc'          => 'Kena i Soqoni',
'fileuploadsummary' => 'Kena i Soqoni:',
'watchthisupload'   => 'Vakaraica toka na tabana oqo',

# Random page
'randompage' => 'Vakawasoma',

'brokenredirects-edit'   => '(Veisautaki)',
'brokenredirects-delete' => '(Vakarusa)',

# Miscellaneous special pages
'newpages-username' => 'Yaca vakayagataki:',
'move'              => 'Toso',
'movethispage'      => 'Toso na tabana oqo',

# Special:AllPages
'allpagessubmit' => 'Lako',

# E-mail user
'defemailsubject' => '{{SITENAME}} I vola livaliva',

# Watchlist
'watchlist'     => 'Ulutaga yadravi',
'watch'         => 'Vakaraica mada',
'watchthispage' => 'Vakaraica toka na tabana oqo',

# Restrictions (nouns)
'restriction-edit' => 'Veisautaki',
'restriction-move' => 'Toso',

# Undelete
'undelete-search-submit' => 'Vaqaqara',

# Contributions
'mycontris' => 'Noqu I takitaki',

# What links here
'whatlinkshere' => 'Sema cava oqo',

# Block/unblock
'ipbreason' => 'Vuna',

# Move page
'move-page-legend' => 'Toso kina yasana kadua',
'movearticle'      => 'Toso kina yasana kadua',
'move-watch'       => 'Vakaraica toka na tabana oqo',
'movepagebtn'      => 'Toso kina yasana kadua',
'movereason'       => 'Vuna',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'Ulutaga taleitaki',
'tooltip-pt-logout'      => 'Curu yani',
'tooltip-ca-move'        => 'Toso na tabana oqo',
'tooltip-search'         => 'Vaqaqara {{SITENAME}}',
'tooltip-p-logo'         => 'Tabana levu',

# Special:NewFiles
'ilsubmit' => 'Vaqaqara',

# Multipage image navigation
'imgmultigo' => 'Lako!',

# Table pager
'table_pager_limit_submit' => 'Lako',

# Special:SpecialPages
'specialpages' => 'Tabana vakamareqeti',

);

==> mediawiki_1.19.2.orig.tar.gz: mediawiki-1.19.2/languages/messages/MessagesFj.php <==
<?php
/** Fijian (Na Vosa Vakaviti)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jose77 (on fj.wikipedia.org)
 */

$messages = array(
# Dates
'sunday'        => 'Sigatabu',
'monday'        => 'Moniti',
'tuesday'       => 'Tusiti',
'wednesday'     => 'Vukelulu',
'thursday'      => 'Lotulevu',
'friday'        => 'Vakaraubuka',
'saturday'      => 'Vakarauwai',
'sun'           => 'Sigatabu',
'mon'           => 'Moniti',
'tue'           => 'Tusiti',
'wed'           => 'Vukelulu',
'thu'           => 'Lotulevu',
'fri'           => 'Vakaraubuka',
'sat'           => 'Vakarauwai',
'january'       => 'Janueri',
'february'      => 'Veverueri',
'march'         => 'Maji',
'april'         => 'Epereli',
'july'          => 'Jiulai',
'august'        => 'Okosita',
'september'     => 'Seviteba',
'october'       => 'Okotova',
'november'      => 'Noveba',
'december'      => 'Tiseba',
'january-gen'   => 'Janueri',
'february-gen'  => 'Veverueri',
'march-gen'     => 'Maji',
'april-gen'     => 'Evereli',
'may-gen'       => 'Me',
'july-gen'      => 'Jiulai',
'august-gen'    => 'Okosita',
'september-gen' => 'Seviteba',
'october-gen'   => 'Okotova',
'november-gen'  => 'Noveba',
'december-gen'  => 'Tiseba',
'jan'           => 'Janueri',
'feb'           => 'Veverueri',
'mar'           => 'Maji',
'apr'           => 'Epereli',
'may'           => 'Me',
'jun'           => 'June',
'jul'           => 'Julai',
'aug'           => 'Okosita',
'sep'           => 'Seviteba',
'oct'           => 'Okotova',
'nov'           => 'Noveba',
'dec'           => 'Tiseba',

'cancel'     => 'Sasamaki',
'mytalk'     => 'Noqu vosa',
'navigation' => 'Vakatasosoko',

# Cologne Blue skin
'qbedit' => 'Veisautaki',

'help'             => 'Veivuke',
'search'           => 'Vaqaqara',
'searchbutton'     => 'Vaqaqara',
'go'               => 'Lako',
'searcharticle'    => 'Lako',
'history_short'    => 'Tukuni',
'printableversion' => 'Tikina e rawa ni tabaki',
'permalink'        => 'Sema tudei',
'edit'             => 'Veisautaki',
'delete'           => 'Vakarusa',
'protect'          => 'Taqomaki',
'unprotect'        => 'Sega ni taqomaki',
'talk'             => 'Veiwasei',
'toolbox'          => 'Kato ni yaya',
'otherlanguages'   => 'Veimataqali vosa',
'jumptonavigation' => 'Vakatasosoko',
'jumptosearch'     => 'Vaqaqara',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Tukutuku kuruvaki',
'currentevents-url'    => 'Project:Tukutuku kuruvaki',
'edithelp'             => 'Veivukei',
'mainpage'             => 'Tabana levu',
'mainpage-description' => 'Tabana levu',
'portal'               => 'Soqosoqo toso',

'editsection' => 'Veisautaki',
'editold'     => 'Veisautaki',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Vola volai',

# Login and logout pages
'yourname'           => 'Yaca vakayagataki',
'yourpassword'       => 'Yaca vuni',
'yourpasswordagain'  => 'Vola tale na Yaca vuni',
'remembermypassword' => 'Nanuma na yacaqu ena komipiuta oqo (for a maximum of $1 {{PLURAL:$1|day|days}})',
'login'              => 'Curu mai',
'userlogin'          => 'Curu mai / Dolava nomu Akaude',
'logout'             => 'Curu yani',
'userlogout'         => 'Curu yani',
'nologinlink'        => 'Dolava nomu Akaude',
'createaccount'      => 'Dolava nomu Akaude',
'gotaccountlink'     => 'Curu mai',

# Edit pages
'summary'      => 'Kena i Soqoni:',
'watchthis'    => 'Vakaraica toka na tabana oqo',
'savearticle'  => 'Vakabula na tabana oqo',
'showpreview'  => 'Vakaraitaka na kenai yaloyalo',
'showdiff'     => 'Vakaritaka na veisau',
'loginreqlink' => 'Curu mai',

# Search results
'powersearch' => 'Vaqaqara',

# Preferences page
'mypreferences'     => 'Ulutaga taleitaki',
'searchresultshead' => 'Vaqaqara',
'youremail'         => 'I vola livaliva *:',
'username'          => 'Yaca vakayagataki:',
'email'             => 'I vola livaliva',

# Recent changes
'recentchanges' => 'Veisau vovou',

# Recent changes linked
'recentchangeslinked'         => 'Veisau e veiwekani',
'recentchangeslinked-feed'    => 'Veisau e veiwekani',
'recentchangeslinked-toolbox' => 'Veisau e veiwekani',

# Upload
'upload'            => 'Vakasinaita',
'uploadbtn'         => 'Vakasinaita',
'filedesc'          => 'Kena i Soqoni',
'fileuploadsummary' => 'Kena i Soqoni:',
'watchthisupload'   => 'Vakaraica toka na tabana oqo',

# Random page
'randompage' => 'Vakawasoma',

'brokenredirects-edit'   => 'Veisautaki',
'brokenredirects-delete' => 'Vakarusa',

# Miscellaneous special pages
'newpages-username' => 'Yaca vakayagataki:',
'move'              => 'Toso',
'movethispage'      => 'Toso na tabana oqo',

# Special:AllPages
'allpagessubmit' => 'Lako',

# E-mail user
'defemailsubject' => '{{SITENAME}} I vola livaliva',

# Watchlist
'watchlist'     => 'Ulutaga yadravi',
'watch'         => 'Vakaraica mada',
'watchthispage' => 'Vakaraica toka na tabana oqo',

# Restrictions (nouns)
'restriction-edit' => 'Veisautaki',
'restriction-move' => 'Toso',

# Undelete
'undelete-search-submit' => 'Vaqaqara',

# Contributions
'mycontris' => 'Noqu I takitaki',

# What links here
'whatlinkshere' => 'Sema cava oqo',

# Block/unblock
'ipbreason' => 'Vuna',

# Move page
'move-page-legend' => 'Toso kina yasana kadua',
'movearticle'      => 'Toso kina yasana kadua',
'move-watch'       => 'Vakaraica toka na tabana oqo',
'movepagebtn'      => 'Toso kina yasana kadua',
'movereason'       => 'Vuna',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'Ulutaga taleitaki',
'tooltip-pt-logout'      => 'Curu yani',
'tooltip-ca-move'        => 'Toso na tabana oqo',
'tooltip-search'         => 'Vaqaqara {{SITENAME}}',
'tooltip-p-logo'         => 'Tabana levu',

# Special:NewFiles
'ilsubmit' => 'Vaqaqara',

# Multipage image navigation
'imgmultigo' => 'Lako!',

# Table pager
'table_pager_limit_submit' => 'Lako',

# Special:SpecialPages
'specialpages' => 'Tabana vakamareqeti',

);
